@@ -690,6 +690,9 @@ bool atominter::beforeParse( pnode* parent )
 {
    bool lResult = true;
 
+	if( parent )
+	{
+	}
    return lResult;
 }
 //---------------------------------------------------------------------------
@@ -1304,6 +1307,10 @@ void atominter::Add2Log( AnsiString Text, bool Clear )
       }
       MainForm->Log->Lines->Add( Text );
    }
+	#else
+	if( Text.Length() && Clear )
+	{
+	}
    #endif
    //fprintf( flog, "%s\n", Text.c_str() );
 }
