@@ -693,7 +693,7 @@ CMatrix operator*( const CMatrix& a, const CMatrix& b )
    CMatrix v;
    CComplex c;
    int y, x, j;
-   bool lError;
+   // bool lError;
 
    if( a.Cols == b.Rows )
    {
@@ -785,7 +785,7 @@ CMatrix operator/( const CMatrix& a, const CComplex& b )
 CMatrix operator^( const CMatrix& a, const int& b )
 {
    CMatrix v;
-   int j, i;
+   int j; //, i;
 
    if( a.Cols == a.Rows )
    {
@@ -909,7 +909,7 @@ CMatrix Inverse( const CMatrix& a )
    CMatrix v;
    CComplex s, t, c, c1, c2;
    int size;
-   int x, y;
+   // int x, y;
    int j, i, k;
 
    if( a.Rows != a.Cols )
@@ -1032,7 +1032,10 @@ AnsiString MatrixToStrF( CMatrix m, int prec )
 CMatrix StrToMatrix( AnsiString Text )
 {
    CMatrix m;
-   
+
+	if( Text.Length() > 0 )
+	{
+	}   
    return m;
 }
 //---------------------------------------------------------------------------
