@@ -122,6 +122,7 @@ afunc _funcs[] = {
                  { sfDec, "Dec", 1 },
                  { sfHex, "Hex", 1 },
                  { sfOct, "Oct", 1 },
+                 { sfEex, "Eex", 1 },
                  
                  { sfAnd, "And", 2 },
                  { sfOr, "Or", 2 },
@@ -174,7 +175,9 @@ const char* _errmsgs[] = {
 int split2strings( char* cmdline, TStringList* Strings, bool caseSens = true )
 {
    AnsiString p, s;
-   int len, count;
+   int len, count = 0;
+
+	if( caseSens ) {}
 
    if( !Strings )
    {
@@ -480,7 +483,7 @@ bool atomstack::drop( int index )
    bool lResult = false;
    if( _ptr >= 0 && index >= 0 && index <= _ptr )
    {
-      int i, j;
+      int j;
       
       for( j = _ptr - index; j < _ptr; j++ )
       {
@@ -517,7 +520,7 @@ bool atomstack::totop( int index )
    if( _ptr >= 0 && index > 0 && index <= _ptr )
    {
       atom a = *( _atoms[ _ptr - index ] );
-      int i, j;
+      int j;
       
       for( j = _ptr - index; j < _ptr; j++ )
       {
@@ -1165,6 +1168,22 @@ bool atomstack::eval( TStackFunc func )
          }
          break;
 
+         case sfEex:
+			if( argv[ 0 ].format() == aifExp )
+			{
+         	res = exp2num( argv[ 0 ] );
+			}
+			else
+			{
+				res = num2exp( argv[ 0 ] );
+			}
+
+         if( res.isnull() )
+         {
+            _errcode = 11;
+         }
+         break;
+
          case sfAnd:
          res = aand( argv[ 0 ], argv[ 1 ] );
          if( res.isnull() )
@@ -1948,7 +1967,7 @@ bool atomstack::save( FILE* f )
    {
       bool tmpres;
       int written = 0;
-      int j, cnt;
+      int j; //, cnt;
       atom a;
       
       written += fwrite( "STACK", 1, 6, f );
@@ -1981,7 +2000,8 @@ bool atomstack::load( FILE* f )
       char buf[ 10 ];
       bool tmpres;
       int readed = 0;
-      int r, j, cnt;
+      // int r;
+		int j, cnt;
       atom a;
       
       readed += fread( buf, 1, 6, f );
