@@ -296,7 +296,7 @@ XString XString::Trim( void ) const
 //---------------------------------------------------------------------------------
 bool XString::IsInteger() const
 {
-   int j, value;
+   int j;
    bool lCorrect = true;
 
    for( j = 0; j < (int)strlen( Buffer ) && lCorrect; j++ )
@@ -317,7 +317,6 @@ bool XString::IsDouble() const
    int j, len;
    bool lCorrect = true;
    bool lDot = false;
-   char buf[ 10 ];
 
    if( Buffer )
    {
@@ -421,7 +420,7 @@ int XString::ToInt( void ) const
 double XString::ToDouble( void ) const
 {
    int j, start, e_pos, len;
-   double value;
+   double value = 0.0;
 
    if( IsDouble() )
    {
@@ -430,7 +429,6 @@ double XString::ToDouble( void ) const
       double t;
       double sign;
       bool lExit;
-      char buf[ 1000 ];
 
       if( Buffer[ 0 ] == '-' )
       {
@@ -501,10 +499,6 @@ double XString::ToDouble( void ) const
          }
       }
    }
-   else
-   {
-      value = 0.0;
-   }
    return value;
 }
 //---------------------------------------------------------------------------------
@@ -715,7 +709,7 @@ XString FloatToStr( double Value )
 //---------------------------------------------------------------------------------
 XString DoubleToStr( double Value, int Prec )
 {
-   bool lExit;
+   //bool lExit;
    char buf[ 100 ];
    if( Prec < 0 )
    {
@@ -897,7 +891,7 @@ int BinStrToInt( XString Str )
 //---------------------------------------------------------------------------------
 bool IsInteger( XString Str )
 {
-   int j, len, value;
+   int j, len; //, value;
    bool lCorrect = true;
 
    len = Str.Length();
@@ -919,7 +913,6 @@ bool IsDouble( XString Str )
    int j, len;
    bool lCorrect = true;
    bool lDot = false;
-   char buf[ 10 ];
 
    if( Str.Length() > 0 )
    {
