@@ -292,8 +292,6 @@ atom::atom( const char* str )
      _name(NULL),
      _valid(false)
 {
-   int len;
-
    _format = aifDec;
    if( str )
    {
@@ -507,7 +505,7 @@ const atom& atom::operator=( const atom& a )
 //-----------------------------------------------------------------------------
 atom atom::operator!( void )
 {
-   bool b;
+   bool b = false;
    atom x;
    if( _type == aBoolean )
    {
@@ -667,9 +665,9 @@ bool atom::save( FILE* f )
 
    if( f )
    {
-      double re, im;
+      //double re, im;
       int written = 0;
-      int j, x, y;
+      //int j, x, y;
       int namelen = _name ? strlen( _name ) + 1 : 0;
       int size = 3 * sizeof( int ) + atomsize() + sizeof( bool );
       if( namelen )
@@ -753,9 +751,9 @@ bool atom::load( FILE* f )
    
    if( f )
    {
-      double re, im;
+      // double re, im;
       int readed = 0;
-      int j, x, y, r;
+      int x;
       int namelen; // = _name ? strlen( _name ) + 1 : 0;
       int size; // = 3 * sizeof( int ) + atomsize() + sizeof( bool );
       
@@ -843,7 +841,7 @@ bool atom::load( FILE* f )
 //-----------------------------------------------------------------------------
 int atom::atomsize( void ) const
 {
-   int i;
+   int i = 0;
    switch( _type )
    {
       case aInteger:
@@ -896,10 +894,10 @@ void atom::makestrbuf( char* buf )
 const char* atom::getstring( int prec )
 {  
    char tmpbuf[ 200 ];
-   char t1[ 20 ];
-   char t2[ 20 ];
-   int j;
-   bool lExit;
+   //char t1[ 20 ];
+   //char t2[ 20 ];
+   //int j;
+   //bool lExit;
    
    if( prec < 0 )
    {
@@ -1013,7 +1011,7 @@ const char* atom::getstring( int prec )
       break;
       
       default:
-      sprintf( tmpbuf, "NULL\0" );
+      sprintf( tmpbuf, "NULL" );
       break;
    }
    //if( _name )
@@ -1924,7 +1922,7 @@ atom factorial( atom& a )
       
       if( (double)( i ) == d && i >= 0 )
       {
-         int j, res;
+         int j, res = 0;
       
          if( i == 0 || i == 1 )
          {
@@ -2440,6 +2438,28 @@ atom int2hex( atom& a )
    return x;
 }
 //-----------------------------------------------------------------------------
+atom num2exp( atom& a )
+{
+   atom x;
+
+   if( a.type() == aInteger || a.type() == aDouble )
+   {
+      x = atom( (double)( a ), aifExp );
+   }
+   return x;
+}
+//-----------------------------------------------------------------------------
+atom exp2num( atom& a )
+{
+   atom x;
+
+   if( a.type() == aInteger || a.type() == aDouble )
+   {
+      x = atom( (double)( a ), aifDec );
+   }
+   return x;
+}
+//-----------------------------------------------------------------------------
 atom aand( atom& a, atom& b )
 {
    atom x;
