@@ -5,6 +5,8 @@
 
 #ifdef _WIN32
 #include <windows.h>
+#else
+#include <qmessagebox.h>
 #endif
 
 #include "primes.h"
@@ -375,7 +377,7 @@ bool isrealstr( const char* str )
 bool iscomplexstr( const char* str )
 {
    bool res = false;
-   char buf[ 100 ];
+   // char buf[ 100 ];
    int len;
    
    len = strlen( str );
@@ -510,7 +512,7 @@ bool ismeasurestr( const char* str )
 {
    bool res = false;
    char buf1[ 100 ];
-   char buf2[ 100 ];
+   // char buf2[ 100 ];
 
    int len = strlen( str );
    int pos = strpos( str, '_' );
@@ -569,6 +571,7 @@ double gamma( double x )
        -0.54e-14,
         0.14e-14};
 
+	 r = 0.0;
     if (x > 171.0) return 1e308;    // This value is an overflow flag.
     if (x == (int)x) {
         if (x > 0.0) {
@@ -921,7 +924,13 @@ void MsgBox( AnsiString Message, int Params )
       Params = MB_OK;
    }
    MessageBox( 0, Message.c_str(), "AStack", Params );
-   #endif
+	#else
+	if( !Params ) 
+	{
+		Params = 1;
+	}
+	QMessageBox::information( 0, "AStack", Message.c_str() );
+	#endif
 }
 //-----------------------------------------------------------------------------
 
