@@ -457,7 +457,7 @@ TCalcButton* TCalc::GetButtonByAction( TButtonAction Action )
 
 TButtonAction TCalc::getButtonAction( TCalcButton* Button )
 {
-   TButtonAction a;
+   TButtonAction a = baUnknown;
 
    if( Button )
    {
@@ -1375,7 +1375,7 @@ int TCalc::UOMCategory( void )
 
 int TCalc::UOMUnits( int Category, AnsiString Description )
 {
-   int j, res, cat;
+   int j, res; // , cat;
    TStrings* uomStr = new TStrings();
    TStrings* uomDsc = new TStrings();
    TCalcMenu* mnu;
@@ -1449,15 +1449,15 @@ bool TCalc::LoadState( void )
    QDir qdir;
    QString file = qdir.homeDirPath() + QString( "/.pgcalcrc" );
    QString filexml = qdir.homeDirPath() + QString( "/.pgcalcxmlrc" );
-   FILE* f;
+   // FILE* f;
 
       xmlnode* xmain;
       xmlnode* xvar;
       xmlnode* xpos;
       xmlnode* xrpn;
       xmlnode* xalg;
-		xmlnode* xtvm;
-		xmlnode* xconv;
+      xmlnode* xtvm;
+      xmlnode* xconv;
       
       xmltree* xtree = new xmltree();
       
@@ -1626,13 +1626,13 @@ bool TCalc::LoadState( void )
 bool TCalc::SaveState( void )
 {
    bool lResult = true;
-   int res;
+   // int res;
    //AnsiString path = GetStatePath() + "\\PG Calculator";
    QDir qdir;
    QString path = qdir.homeDirPath();
    QString file = qdir.homeDirPath() + QString( "/.pgcalcrc" ); //path + "\\pgcalc.dat";
    QString filexml = qdir.homeDirPath() + QString( "/.pgcalcxmlrc" ); //path + "\\pgcalc.dat";
-   FILE* f;
+   // FILE* f;
 
    //fprintf( stderr, "Writing PG Calculator state to %s...\n", (const char*)( file ) );
    if( lResult )
@@ -1640,8 +1640,8 @@ bool TCalc::SaveState( void )
          RECT r;
          int j, x, y;
          char state;
-         int written = 0;
-         char descr[] = "PG";
+         // int written = 0;
+         // char descr[] = "PG";
          xmlnode* xmain;
          xmlnode* xpos;
          xmlnode* xrpn;    
@@ -1720,6 +1720,8 @@ bool TCalc::SaveState( void )
 
 void TCalc::paintEvent( QPaintEvent* e )
 {
+	if( e ) {}
+
    if( LCD )
    {
       LCD->clear();
@@ -1736,6 +1738,8 @@ void TCalc::paintEvent( QPaintEvent* e )
 void TCalc::mousePressEvent( QMouseEvent* e )
 {
    TCalcButton* b;
+
+	if( e ) {}
    
    b = Buttons->itemAt( e->x(), e->y() );
    if( b )
@@ -1764,7 +1768,7 @@ void TCalc::mouseReleaseEvent( QMouseEvent* e )
 {
    TButtonAction Action;
    TCalcButton* b;
-   
+
    if( CurrentButton )
    {
  		b = Buttons->itemAt( e->x(), e->y() );
@@ -1847,6 +1851,8 @@ void TCalc::keyPressEvent( QKeyEvent* e )
 void TCalc::keyReleaseEvent( QKeyEvent* e )
 {
    TButtonAction Action;
+
+	if( e ) {}
    
    if( CurrentButton )
    {
@@ -1860,6 +1866,8 @@ void TCalc::keyReleaseEvent( QKeyEvent* e )
 
 void TCalc::showEvent( QShowEvent* e )
 {
+	if( e ) {}
+
    SysTray->hide();
 }
 
