@@ -456,7 +456,7 @@ xmlnode* xmlnode::getNodeByName( AnsiString AName )
 //---------------------------------------------------------------------------
 AnsiString xmlnode::getNodeValue( AnsiString AName, AnsiString ADefault )
 {
-   AnsiString p;
+   // AnsiString p;
    xmlnode* n = getNodeByName( AName );
    if( n )
    {
@@ -466,6 +466,8 @@ AnsiString xmlnode::getNodeValue( AnsiString AName, AnsiString ADefault )
    {
       #ifdef __BORLANDC__
       throw Exception( "Node [" + AName + "] doens't exist under node [" + FName + "]..." );
+		#else
+		return ADefault;
       #endif
    }
 }
@@ -682,7 +684,7 @@ void xmltree::translateBuffer( char* Buffer )
    AnsiString n, v;
    xmlnode* node = NULL;
    xmlnode* parent;
-   bool nodeEmpty;
+   bool nodeEmpty = false;
    bool isComment;
    int quota;
 
@@ -829,7 +831,7 @@ void xmltree::translateAttributes( xmlnode* Parent )
 {
    xmlnode* n;
    AnsiString p;
-   int pos;
+   // int pos;
 
    n = getFirstCh( Parent );
    while( n )
@@ -1012,7 +1014,7 @@ void xmltree::loadFromFile( AnsiString FileName )
       char z;
       int j;
       char* buf = new char[ size ];
-      int readed;
+      // int readed;
       FILE* f = fopen( FileName.c_str(), "rt" );
 
       if( f )
@@ -1173,5 +1175,6 @@ void __fastcall TXMLTree::SaveToStream( TStream* Stream )
 //---------------------------------------------------------------------------
 #endif
 
+#ifdef __BORLANDC__
 #pragma package(smart_init)
-
+#endif
