@@ -231,10 +231,10 @@ void TCalcRPN::ExecAction( TButtonAction& Action )
    atom a;
    AnsiString p;
    bool lProcessed = true;
-   bool lExit;
-   char ChrValue;
-   char digits[ 10 ] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9' };
-   TButtonAction bdigit[ 10 ] = { ba0, ba1, ba2, ba3, ba4, ba5, ba6, ba7, ba8, ba9 };
+   // bool lExit;
+   // char ChrValue;
+   // char digits[ 10 ] = { '0', '1', '2', '3', '4', '5', '6', '7', '8', '9' };
+   // TButtonAction bdigit[ 10 ] = { ba0, ba1, ba2, ba3, ba4, ba5, ba6, ba7, ba8, ba9 };
    int j;
    
    TCalcObject::ExecAction( Action );
@@ -312,7 +312,11 @@ void TCalcRPN::ExecAction( TButtonAction& Action )
    }
    else if( Action == baEex )
    {
-      if( LCD->InpLine->Buffer.Pos( "E" ) <= 0 )
+		if( LCD->InpLine->Buffer.Length() == 0 )
+		{
+			Eval( sfEex );
+		}
+      else if( LCD->InpLine->Buffer.Pos( "E" ) <= 0 )
       {
          LCD->InpLine->InsertText( "E" );
       }
@@ -759,7 +763,7 @@ void TCalcRPN::ExecAction( TButtonAction& Action )
       Calc.CmdCatalog();
       Action = baUnknown;
       return;
-      /*
+      
       TCalcMenu* mnu = new TCalcMenu( Owner, this );
       mnu->SetCaption( "Test menu" );
       for( j = 0; j < 50; j++ )
@@ -767,9 +771,9 @@ void TCalcRPN::ExecAction( TButtonAction& Action )
          mnu->AddItem( AnsiString( "ITEM " ) + IntToStr( j + 1 ), j + 1 );
       }      
       mnu->ShowModal();
-      */
-   //}
-
+      
+   }
+	*/
    else if( Action == baUp || Action == baHist )
    {
       if( Stack->count() )
@@ -832,9 +836,8 @@ void TCalcRPN::ExecAction( TButtonAction& Action )
 }
 //---------------------------------------------------------------------------
 void TCalcRPN::InputChar( int Char )
-{/*
-   LCD->InsertToBuffer( (char)Char );
-   Refresh();*/
+{
+	if( Char ) {}
 }
 //---------------------------------------------------------------------------
 void TCalcRPN::SetMode( int AMode )
@@ -869,6 +872,7 @@ void TCalcRPN::SetMode( int AMode )
 //---------------------------------------------------------------------------
 void TCalcRPN::ExecMenuCmd( int AMenuCmd )
 {
+	if( AMenuCmd ) {}
 }
 //---------------------------------------------------------------------------
 void TCalcRPN::BackSpace( void )
@@ -944,7 +948,7 @@ bool TCalcRPN::Push( AnsiString p )
 {
    atom a;
    bool res;
-   char buf[ 3 ];
+   // char buf[ 3 ];
    int const_index;
    int var_index;
    int func_index = -1;
