@@ -25,7 +25,9 @@ class TCalcUnitConv : public TCalcObject
    atomlist* results;
    
    double value;
-   int basec, basecidx, baseuidx;
+   int basec;
+	int basecidx;
+	int baseuidx;
    AnsiString baseu;
    
    public:
